@@ -56,11 +56,12 @@ REQUEST_HEADERS = {
 }
 
 # URL to seed all of the auth requests
-SEED_URL = "https://www.linkedin.com/uas/login"
-LOGIN_URL = "https://www.linkedin.com/checkpoint/lg/login-submit"
-VERIFY_URL = "https://www.linkedin.com/checkpoint/challenge/verify"
-REALTIME_CONNECT_URL = "https://realtime.www.linkedin.com/realtime/connect"
 HEARTBEAT_URL = "https://realtime.www.linkedin.com/realtime/realtimeFrontendClientConnectivityTracking"  # noqa: E501
+LOGIN_URL = "https://www.linkedin.com/checkpoint/lg/login-submit"
+LOGOUT_URL = "https://www.linkedin.com/uas/logout"
+REALTIME_CONNECT_URL = "https://realtime.www.linkedin.com/realtime/connect"
+SEED_URL = "https://www.linkedin.com/uas/login"
+VERIFY_URL = "https://www.linkedin.com/checkpoint/challenge/verify"
 
 LINKEDIN_BASE_URL = "https://www.linkedin.com"
 API_BASE_URL = f"{LINKEDIN_BASE_URL}/voyager/api"
@@ -109,11 +110,7 @@ class LinkedInMessaging:
     @property
     def has_auth_cookies(self) -> bool:
         cookie_names = {c.key for c in self.session.cookie_jar}
-        return (
-            "liap" in cookie_names
-            and "li_at" in cookie_names
-            and "JSESSIONID" in cookie_names
-        )
+        return "li_at" in cookie_names and "JSESSIONID" in cookie_names
 
     async def logged_in(self) -> bool:
         if not self.has_auth_cookies:
@@ -196,6 +193,17 @@ class LinkedInMessaging:
             # TODO (#1) can we scrape anything from the page?
             raise Exception("Failed to log in.")
 
+    async def logout(self) -> bool:
+        csrf_token = self.session.headers.get("csrf-token")
+        if not csrf_token:
+            return True
+        response = await self.session.get(
+            LOGOUT_URL,
+            params={"csrfToken": csrf_token},
+            allow_redirects=False,
+        )
+        return response.status == 303
+
     # endregion
 
     # region Conversations
